<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>EllipseCPP</name>
    <message>
        <source>&amp;Full Ellipse</source>
        <translation type="vanished">&amp;Polna elipsa</translation>
    </message>
    <message>
        <source>&amp;Full Ellipse with Center, Point, Ratio</source>
        <translation type="vanished">&amp;Polna elipsa s središčem, točko, razmerjem</translation>
    </message>
    <message>
        <location filename="../EllipseCPPInit.js" line="+2"/>
        <source>&amp;Ellipse (Center, Point, Ratio)</source>
        <translation>&amp;Elipsa (Središče, Točka, Razmerje)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw full ellipse from center, major point and ratio</source>
        <translation>Nariši polno elipso iz centra, glavne točke ter razmerja</translation>
    </message>
</context>
</TS>
